==> haskell-dataenc-0.14.0.7-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-dataenc.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dataenc
version: 0.14.0.7
id: dataenc-0.14.0.7-CKvD5tlFA4uISx789zJp9p
key: dataenc-0.14.0.7-CKvD5tlFA4uISx789zJp9p
license: BSD3
copyright: Magnus Therning, 2007-2012, Gracjan Polak, 2014
maintainer: Gracjan Polak <gracjanpolak@gmail.com>
homepage: http://www.haskell.org/haskellwiki/Library/Data_encoding
synopsis: Data encoding library
description:
    Data encoding library currently providing Base16, Base32,
    Base32Hex, Base64, Base64Url, Base85, Python string escaping,
    Quoted-Printable, URL encoding, uuencode, xxencode, and yEncoding.
category: Codec
author: Magnus Therning
exposed: True
indefinite: False
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.DataEncoding Codec.Binary.PythonString
    Codec.Binary.QuotedPrintable Codec.Binary.Url Codec.Binary.Uu
    Codec.Binary.Xx Codec.Binary.Yenc
hidden-modules: Codec.Binary.Util
abi: d4b5470dca59ce0a2ecaa68fed11e3e3
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/dataenc-0.14.0.7
library-dirs: /usr/lib/ghc-8.2.1/site-local/dataenc-0.14.0.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/dataenc-0.14.0.7
hs-libraries: HSdataenc-0.14.0.7-CKvD5tlFA4uISx789zJp9p
depends:
    array-0.5.2.0 base-4.10.0.0 containers-0.5.10.2
abi-depends: array-0.5.2.0=5abf025fb7bf60079ec1f42bab285152
             base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             containers-0.5.10.2=e086202b65ca66a107fcba9d846fc3e0
haddock-interfaces: /usr/share/doc/haskell-dataenc/html/dataenc.haddock
haddock-html: /usr/share/doc/haskell-dataenc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dataenc-0.14.0.7-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-dataenc.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dataenc
version: 0.14.0.7
id: dataenc-0.14.0.7-Blno6K6nv6cLpCKak3yk74
key: dataenc-0.14.0.7-Blno6K6nv6cLpCKak3yk74
license: BSD3
copyright: Magnus Therning, 2007-2012, Gracjan Polak, 2014
maintainer: Gracjan Polak <gracjanpolak@gmail.com>
homepage: http://www.haskell.org/haskellwiki/Library/Data_encoding
synopsis: Data encoding library
description:
    Data encoding library currently providing Base16, Base32,
    Base32Hex, Base64, Base64Url, Base85, Python string escaping,
    Quoted-Printable, URL encoding, uuencode, xxencode, and yEncoding.
category: Codec
author: Magnus Therning
exposed: True
indefinite: False
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.DataEncoding Codec.Binary.PythonString
    Codec.Binary.QuotedPrintable Codec.Binary.Url Codec.Binary.Uu
    Codec.Binary.Xx Codec.Binary.Yenc
hidden-modules: Codec.Binary.Util
abi: ab209199fbd7cb1f08ac21877ddf8c32
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/dataenc-0.14.0.7
library-dirs: /usr/lib/ghc-8.2.2/site-local/dataenc-0.14.0.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/dataenc-0.14.0.7
hs-libraries: HSdataenc-0.14.0.7-Blno6K6nv6cLpCKak3yk74
depends:
    array-0.5.2.0 base-4.10.1.0 containers-0.5.10.2
abi-depends: array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
haddock-interfaces: /usr/share/doc/haskell-dataenc/html/dataenc.haddock
haddock-html: /usr/share/doc/haskell-dataenc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
